summaryrefslogtreecommitdiff
path: root/gl/version-etc.c
diff options
context:
space:
mode:
authorSimon Josefsson <simon@josefsson.org>2009-03-04 15:17:23 +0100
committerSimon Josefsson <simon@josefsson.org>2009-03-04 15:17:23 +0100
commite3b1519809de90067e0058b0a43e3817de134f72 (patch)
treee2bf51ae0b0105b35be2962c7ae50fb803bdcb54 /gl/version-etc.c
parentf410d3a7c70b75b65fcec74542e0cf7d8817d81c (diff)
downloadlibtasn1-e3b1519809de90067e0058b0a43e3817de134f72.tar.gz
libtasn1-e3b1519809de90067e0058b0a43e3817de134f72.tar.bz2
libtasn1-e3b1519809de90067e0058b0a43e3817de134f72.zip
Update gnulib files.
Diffstat (limited to 'gl/version-etc.c')
-rw-r--r--gl/version-etc.c22
1 files changed, 18 insertions, 4 deletions
diff --git a/gl/version-etc.c b/gl/version-etc.c
index 823e085..2258c2e 100644
--- a/gl/version-etc.c
+++ b/gl/version-etc.c
@@ -1,5 +1,5 @@
-/* Utility to help print --version output in a consistent format.
- Copyright (C) 1999-2008 Free Software Foundation, Inc.
+/* Print --version and bug-reporting information in a consistent format.
+ Copyright (C) 1999-2009 Free Software Foundation, Inc.
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
#include "gettext.h"
#define _(msgid) gettext (msgid)
-enum { COPYRIGHT_YEAR = 2008 };
+enum { COPYRIGHT_YEAR = 2009 };
/* Like version_etc, below, but with the NULL-terminated author list
provided via a variable of type va_list. */
@@ -66,7 +66,7 @@ version_etc_va (FILE *stream,
fputs (_("\
\n\
-License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n\
This is free software: you are free to change and redistribute it.\n\
There is NO WARRANTY, to the extent permitted by law.\n\
\n\
@@ -170,3 +170,17 @@ version_etc (FILE *stream,
va_start (authors, version);
version_etc_va (stream, command_name, package, version, authors);
}
+
+void
+emit_bug_reporting_address (void)
+{
+ /* TRANSLATORS: The placeholder indicates the bug-reporting address
+ for this package. Please add _another line_ saying
+ "Report translation bugs to <...>\n" with the address for translation
+ bugs (typically your translation team's web or email address). */
+ printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+ printf (_("%s home page: <http://www.gnu.org/software/%s/>.\n"),
+ PACKAGE_NAME, PACKAGE);
+ fputs (_("General help using GNU software: <http://www.gnu.org/gethelp/>.\n"),
+ stdout);
+}